@@ -186,6 +186,11 @@ def read_bam(f, sparse=True, as_df=False, mapq=0, required_flag=0, filter_flag=1
         print("bamread must be installed to read bam. Use `conda install -c bioconda bamread` or `pip install bamread` to install it.")
         sys.exit(1)
 
+    if bamread.__version__ in ["0.0.1", "0.0.2", "0.0.3", "0.0.4",
+                               "0.0.5", "0.0.6", "0.0.7", "0.0.8", "0.0.9"]:
+        print("bamread not recent enough. Must be 0.0.10 or higher. Use `conda install -c bioconda 'bamread>=0.0.10'` or `pip install bamread>=0.0.10` to install it.")
+        sys.exit(1)
+
     if sparse:
         df = bamread.read_bam(f, mapq, required_flag, filter_flag)
     else:
@@ -254,6 +259,10 @@ def read_gtf(f, full=True, as_df=False, nrows=None, duplicate_attr=False):
 
         Path to GTF file.
 
+    full : bool, default True
+
+        Whether to read and interpret the annotation column.
+
     as_df : bool, default False
 
         Whether to return as pandas DataFrame instead of PyRanges.
@@ -298,7 +307,10 @@ def read_gtf(f, full=True, as_df=False, nrows=None, duplicate_attr=False):
 
     _skiprows = skiprows(f)
 
-    gr = read_gtf_full(f, as_df, nrows, _skiprows, duplicate_attr)
+    if full:
+        gr = read_gtf_full(f, as_df, nrows, _skiprows, duplicate_attr)
+    else:
+        gr = read_gtf_restricted(f, _skiprows, as_df=False, nrows=None)
 
     return gr
 
@@ -357,10 +369,6 @@ def to_rows(anno):
                                       # l[:-1] removes final ";" cheaply
                                       for kv in l[:-1].split("; ")]})
 
-    # for l in anno:
-    #     l = l.replace('"', '').replace(";", "").split()
-    #     rowdicts.append({k: v for k, v in zip(*([iter(l)] * 2))})
-
     return pd.DataFrame.from_dict(rowdicts).set_index(anno.index)
 
 
@@ -388,8 +396,8 @@ def to_rows_keep_duplicates(anno):
 
 
 def read_gtf_restricted(f,
+                        skiprows,
                         as_df=False,
-                        skiprows=0,
                         nrows=None):
     """seqname - name of the chromosome or scaffold; chromosome names can be given with or without the 'chr' prefix. Important note: the seqname must be one used within Ensembl, i.e. a standard chromosome name or an Ensembl identifier such as a scaffold ID, without any additional content such as species or assembly. See the example GFF output below.
     # source - name of the program that generated this feature, or the data source (database or project name)
@@ -415,6 +423,7 @@ def read_gtf_restricted(f,
         names="Chromosome Feature Start End Score Strand Attribute".split(),
         dtype=dtypes,
         chunksize=int(1e5),
+        skiprows=skiprows,
         nrows=nrows)
 
     dfs = []
@@ -457,7 +466,7 @@ def to_rows_gff3(anno):
     return pd.DataFrame.from_dict(rowdicts).set_index(anno.index)
 
 
-def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
+def read_gff3(f, full=True, annotation=None, as_df=False, nrows=None):
 
     """Read files in the General Feature Format.
 
@@ -467,6 +476,10 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
 
         Path to GFF file.
 
+    full : bool, default True
+
+        Whether to read and interpret the annotation column.
+
     as_df : bool, default False
 
         Whether to return as pandas DataFrame instead of PyRanges.
@@ -481,6 +494,10 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
     pyranges.read_gtf : read files in the Gene Transfer Format
     """
 
+    _skiprows = skiprows(f)
+
+    if not full:
+        return read_gtf_restricted(f, _skiprows, as_df=as_df, nrows=nrows)
 
     dtypes = {
         "Chromosome": "category",
@@ -499,7 +516,7 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
         names=names,
         dtype=dtypes,
         chunksize=int(1e5),
-        skiprows=skiprows,
+        skiprows=_skiprows,
         nrows=nrows)
 
     dfs = []
